Struct refuse::LocalPool

source ·
pub struct LocalPool { /* private fields */ }
A pool of garbage collected values.

Values from any pool can be read using any CollectionGuard. Using independent pools for specific types of data that are meant to be shared across many threads might be beneficial. However, an individual local pool will not be fully deallocated until all values allocated have been collected. Because of this, it may make sense to store some types in their own pool, ensuring their collection is independent of how the values are used amongst other threads.

Implementations

source

impl LocalPool

source

pub fn enter(&self) -> CollectionGuard<'_>

Acquires a collection guard for this pool.