Struct refuse::WouldDeadlock

source ·
pub struct WouldDeadlock;
An error indicating an operation would deadlock.

CollectionGuard::acquire can be called multiple times from the same thread, but some operations require that all guards for the current thread have been released before performing. This error signals when an operation can’t succeed because the current thread has an outstanding guard that must be dropped for the operation to be able to be performed.

use refuse::{CollectionGuard, WouldDeadlock};

let mut guard1 = CollectionGuard::acquire();
let guard2 = CollectionGuard::acquire();

assert_eq!(guard1.try_collect(), Err(WouldDeadlock));

drop(guard2);

assert_eq!(guard1.try_collect(), Ok(()));