Struct refuse::WouldDeadlock
source · pub struct WouldDeadlock;Expand description
An error indicating an operation would deadlock.
CollectionGuard::acquire can be called multiple times from the same
thread, but some operations require that all guards for the current thread
have been released before performing. This error signals when an operation
can’t succeed because the current thread has an outstanding guard that must
be dropped for the operation to be able to be performed.
use refuse::{CollectionGuard, WouldDeadlock};
let mut guard1 = CollectionGuard::acquire();
let guard2 = CollectionGuard::acquire();
assert_eq!(guard1.try_collect(), Err(WouldDeadlock));
drop(guard2);
assert_eq!(guard1.try_collect(), Ok(()));Trait Implementations
sourceimpl Clone for WouldDeadlock
impl Clone for WouldDeadlock
sourcefn clone(&self) -> WouldDeadlock
fn clone(&self) -> WouldDeadlock
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for WouldDeadlock
impl Debug for WouldDeadlock
sourceimpl Display for WouldDeadlock
impl Display for WouldDeadlock
sourceimpl PartialEq for WouldDeadlock
impl PartialEq for WouldDeadlock
sourcefn eq(&self, other: &WouldDeadlock) -> bool
fn eq(&self, other: &WouldDeadlock) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl Copy for WouldDeadlock
impl Eq for WouldDeadlock
impl StructuralPartialEq for WouldDeadlock